#include <stdio.h>
#include <string.h>
#include <cmqc.h>

#if !defined(TRUE)
	#define TRUE 1
#endif

#if defined(WIN32)
    #define QM_DEFAULT "NT_QM"
#elif defined(_AIX)
    #define QM_DEFAULT "SEAIX_QM"
#elif defined(_SOLARIS)
    #define QM_DEFAULT "SUN_QM"
#elif defined(_HPUX)
    #define QM_DEFAULT "HP_QM"
#endif

#define Q1_DEFAULT "L1.Q"
#define KYPROBLEM 0

#if 1
#define XML_MSG "<outer1><tag1>data1</tag1><tag2>data2</tag2><tag3>data3</tag3><reply>data4</reply></outer1>"
#else
#define XML_MSG ""
#endif

//#define XML_MSG "<Container></Container>"

int main(int argc, char **argv)
{
	MQHCONN hConn;
	MQHOBJ requestQHandle;
    MQLONG   openOptions;               /* MQOPEN options                */
    MQOD od,
		 odDefault = {MQOD_DEFAULT};           /* Object Descriptor */
    MQPMO pmo = {MQPMO_DEFAULT};        /* put message options */
    MQGMO gmo = {MQGMO_DEFAULT};        /* get message options */
	MQMD md,
		 mdDefault = {MQMD_DEFAULT};           /* Message Descriptor */
	MQLONG compCode,
		   reason;
	char *qmName,
	     *inputQ,
		 myQueueName[100],
		 messageBuffer[2000],
		 requestId[MQ_MSG_ID_LENGTH];
	int messageBufferLength,
		messageLength,
                keepLooping = 1;

	/* display usage template if requested */
    if (argc == 2 && argv[1][0] == '?' || argc > 1 && argc != 3)
	{
		printf("Usage: %s < <queueManagerName> <queueName>\n",
			    argv[0]);
		return(0);
	}

    if (argc == 3)
    {
		/* progName + qmName + queueName */

        /* read in queue manager name */
		qmName = argv[1];

		/* now read the queue name */
		inputQ = argv[2];
    }
    else
    {
		qmName = QM_DEFAULT;
		inputQ = Q1_DEFAULT;
    }

	printf("Queue manager: %s\n", qmName);
	printf("Queue name: %s\n", inputQ);

	/* connect to queue manager, assume default */
	MQCONN(qmName,
		   &hConn,
		   &compCode,
		   &reason);
	if (reason != MQRC_NONE)
	{
		printf("MQCONN failed with compcode=%d, reason=%d\n", 
			   compCode, reason);
		return(0);
	}

	printf("Connection handle returned is %.8x\n", hConn);

	/* open the specified input queue */
	memcpy(&od, &odDefault, sizeof(od));
	strcpy(myQueueName, inputQ);
	printf("About to open queue '%s'\n", myQueueName);
	strncpy(od.ObjectName,
			myQueueName,
			(size_t)MQ_Q_NAME_LENGTH);

	/* set the open mode */
	openOptions = MQOO_INPUT_AS_Q_DEF + 
		          MQOO_FAIL_IF_QUIESCING; /* open queue for output */

	MQOPEN(hConn,
		   &od,
		   openOptions,
		   &requestQHandle,
		   &compCode,
		   &reason);
	if (reason != MQRC_NONE)
	{
		printf("MQOPEN for input queue '%s' failed with compcode=%d, reason=%d\n",
			   myQueueName, compCode, reason);
		return(0);
	}

    /* do forever */
	messageBufferLength = sizeof(messageBuffer);

	while(keepLooping)
	{
		/* wait forever for next message */
		gmo.Options = MQGMO_WAIT +
		              MQGMO_NO_SYNCPOINT;
        gmo.WaitInterval = MQWI_UNLIMITED;
		memcpy(&md, &mdDefault, sizeof(md));

		memset(messageBuffer, 0, sizeof(messageBuffer));
		printf("About to get message from queue %s\n", myQueueName);

		MQGET(hConn,                        /* connection handle */
			  requestQHandle,               /* object handle */
			  &md,                          /* message descriptor */
			  &gmo,                         /* get message options */
			  messageBufferLength,          /* size of receive buffer */
			  messageBuffer,                /* message buffer */
	  (long *)&messageLength,               /* returned message length */
			  &compCode,                    /* completion code */
			  &reason);                     /* reason code */

		if (reason != MQRC_NONE)
		{
			printf("MQGET failed with compcode=%d, reason=%d\n",
				   compCode, reason);
			return(0);
		}

#if KYPROBLEM
		/* build simple BLOB message */
		strcpy(messageBuffer, "12345");
#elif 0
		/* build the reply message by adding 'reply' to end of request msg */
		strcat(messageBuffer, " (reply)");
#else
		/* build the XML reply message */
		strcpy(messageBuffer, XML_MSG);
#endif
		messageLength = strlen(messageBuffer);

		/* print contents of message */
		printf("Returned message content is '%s'\n",
			   messageBuffer);

		/* put message on reply to queue */
		printf("Requestors reply to queue is '%.*s'\n",
			    sizeof(md.ReplyToQ), md.ReplyToQ);

 	    memcpy(&od, &odDefault, sizeof(od));
		strncpy(od.ObjectName,
				md.ReplyToQ,
				(size_t)MQ_Q_NAME_LENGTH);

		/* set correl id of reply to msg id of request */
		memcpy(requestId, md.MsgId, MQ_MSG_ID_LENGTH);
		memcpy(&md, &mdDefault, sizeof(md));

		memcpy(md.CorrelId, requestId, MQ_CORREL_ID_LENGTH);
		//printf("CorrelId NOT set to MsgId\n");

		memcpy(md.ReplyToQ, "Dummy", 6);


//		messageLength = 0;

	    /* put the message on the queue */
		MQPUT1(hConn,               /* connection handle */
			   &od,                 /* object descriptor */
			   &md,                 /* message descriptor */
			   &pmo,                /* put options */
			   messageLength,       /* msg length */
			   messageBuffer,       /* message buffer */
			   &compCode,           /* completion code */
			   &reason);            /* reason code */

		if (reason != MQRC_NONE)
		{
			printf("MQPUT1 failed with compcode=%d, reason=%d\n",
				   compCode, reason);
			return(0);
		}
	}

	MQDISC(&hConn,
		   &compCode,
		   &reason);
	if (reason != MQRC_NONE)
	{
		printf("MQDISC failed with compcode=%d, reason=%d\n",
			   compCode, reason);
		return(0);
	}

	return(0);
}

