#if !defined(__POSTIT_CONSTANTS_H)
    #define __POSTIT_CONSTANTS_H
/******************************************************************************/
/*                                                                            */
/* Licensed Materials - Property of IBM                                       */
/* (C) Copyright IBM Corp. 2000                                               */
/*                                                                            */
/* Program name    : postit_constants.h                                       */
/*                                                                            */
/* Description     : This header file contains unicode constants for the      */
/*                   postit plug-in node.                                     */
/*                                                                            */
/******************************************************************************/
/*                                                                            */
/* Version 1.0                                                                */
/* Author: Mike Brady                      Date: Jul 2001                     */
/*                                                                            */
/******************************************************************************/

#include <BipCci.h>	  /* Data types for Plug-in Node functions     */

#if defined(WIN32)  // little endian, so no need to shift bytes 
	#define UC(__char) ((CciChar)__char)
	#define UCB ((CciChar)' ')
	#define UCDOT ((CciChar)'.')
#elif defined(_SOLARIS) || defined(_HPUX)
	#define UC(__char) (((CciChar)__char))
	#define UCB (((CciChar)' '))
	#define UCDOT (((CciChar)'.'))
#else
	#define UC(__char) (((CciChar)__char)<<8)
	#define UCB (((CciChar)' ')<<8)
	#define UCDOT (((CciChar)'.')<<8)
#endif

typedef struct postitConstants {
    CciChar 
        *PLUGIN_MESSAGE_CATALOGUE,
        *POSTIT_CREATE_NODE,
        *POSTIT_APPLY_NODE,
        *POSTIT_DELETE_NODE,
        *ATTR_LABEL,
        *ATTR_USER_TRACE_LEVEL,
        *ATTR_TRACE_LEVEL,
        *ATTR_USER_TRACE_FILTER,
        *ATTR_TRACE_FILTER,
        *TERM_IN,
        *TERM_OUT,
        *TERM_FAILURE,
        *ATTR_POSTIT_NAME,
        *ATTR_POSTIT_NAME_DEFAULT_VALUE,
        *ATTR_COPY_DATA_FROM,
        *ATTR_COPY_DATA_FROM_DEFAULT_VALUE,
        *ATTR_COPY_DATA_TO,
        *ATTR_COPY_DATA_TO_DEFAULT_VALUE,
        *ATTR_MATCH_ON,
        *ATTR_MATCH_ON_DEFAULT_VALUE,
        *ATTR_TIMEOUT_SECONDS,
        *ATTR_TIMEOUT_SECONDS_DEFAULT_VALUE,
        *ATTR_NUM_APPLICATIONS,
        *ATTR_NUM_APPLICATIONS_DEFAULT_VALUE,
        *ATTR_POSTIT_SCOPE,
        *ATTR_POSTIT_SCOPE_DEFAULT_VALUE,
        *MATCH_CORRELID_TO_MSGID,
        *MATCH_MSGID_TO_MSGID,
        *MATCH_CORRELID_TO_CORRELID,
        *MATCH_MSGID_TO_CORRELID,
        *MATCH_BOTHIDS,
        *MATCH_ALL_MESSAGES,
        *SCOPE_VALUE_EG,
        *SCOPE_VALUE_BROKER,
        *TERM_NO_DATA_COPIED,
        *TERM_NO_MATCH,
        *ROOT,
        *ROOT_DOT,
        *NULL_LITERAL,
        *POSTIT_PLUGIN_FACTORY;
} postitConstants_t;

/* build static initialisation values for Solaris */
#if defined(_SOLARIS) || defined(_HPUX)

#if defined(GLOBAL_POSTIT_DATA)
CciChar 
    PLUGIN_MESSAGE_CATALOGUE_VAL[sizeof("MQSIV2_postit")*sizeof(CciChar)] =
    {'M','Q','S','I','V','2','_','p','o','s','t','i','t',0},
    POSTIT_CREATE_NODE_VAL[sizeof("PostitCreateNode")*sizeof(CciChar)] =
    {'P','o','s','t','i','t','C','r','e','a','t','e','N','o','d','e',0},
    POSTIT_APPLY_NODE_VAL[sizeof("PostitApplyNode")*sizeof(CciChar)] =
    {'P','o','s','t','i','t','A','p','p','l','y','N','o','d','e',0},
    POSTIT_DELETE_NODE_VAL[sizeof("PostitDeleteNode")*sizeof(CciChar)] =
    {'P','o','s','t','i','t','D','e','l','e','t','e','N','o','d','e',0},
    ATTR_LABEL_VAL[sizeof("label")*sizeof(CciChar)] =
    {'l','a','b','e','l',0},
    ATTR_USER_TRACE_LEVEL_VAL[sizeof("userTraceLevel")*sizeof(CciChar)] =
    {'u','s','e','r','T','r','a','c','e','L','e','v','e','l',0},
    ATTR_TRACE_LEVEL_VAL[sizeof("traceLevel")*sizeof(CciChar)] =
    {'t','r','a','c','e','L','e','v','e','l',0},
    ATTR_USER_TRACE_FILTER_VAL[sizeof("userTraceFilter")*sizeof(CciChar)] =
    {'u','s','e','r','T','r','a','c','e','F','i','l','t','e','r',0},
    ATTR_TRACE_FILTER_VAL[sizeof("traceFilter")*sizeof(CciChar)] =
    {'t','r','a','c','e','F','i','l','t','e','r',0},
    TERM_IN_VAL[sizeof("in")*sizeof(CciChar)] =
    {'i','n',0},
    TERM_OUT_VAL[sizeof("out")*sizeof(CciChar)] =
    {'o','u','t',0},
    TERM_FAILURE_VAL[sizeof("failure")*sizeof(CciChar)] =
    {'f','a','i','l','u','r','e',0},
    ATTR_POSTIT_NAME_VAL[sizeof("PostitName")*sizeof(CciChar)] =
    {'P','o','s','t','i','t','N','a','m','e',0},
    ATTR_POSTIT_NAME_DEFAULT_VALUE_VAL[sizeof("")*sizeof(CciChar)] =
    {0},
    ATTR_COPY_DATA_FROM_VAL[sizeof("CopyDataFrom")*sizeof(CciChar)] =
    {'C','o','p','y','D','a','t','a','F','r','o','m',0},
    ATTR_COPY_DATA_FROM_DEFAULT_VALUE_VAL[sizeof("Root.MQMD.ReplyToQ")*sizeof(CciChar)] =
    {'R','o','o','t','.','M','Q','M','D','.','R','e','p','l','y','T','o','Q',0},
    ATTR_COPY_DATA_TO_VAL[sizeof("CopyDataTo")*sizeof(CciChar)] =
    {'C','o','p','y','D','a','t','a','T','o',0},
    ATTR_COPY_DATA_TO_DEFAULT_VALUE_VAL[sizeof("Root.MQMD.ReplyToQ")*sizeof(CciChar)] =
    {'R','o','o','t','.','M','Q','M','D','.','R','e','p','l','y','T','o','Q',0},
    ATTR_MATCH_ON_VAL[sizeof("MatchOn")*sizeof(CciChar)] =
    {'M','a','t','c','h','O','n',0},
    ATTR_MATCH_ON_DEFAULT_VALUE_VAL[sizeof("CorrelId=OldMsgId")*sizeof(CciChar)] =
    {'C','o','r','r','e','l','I','d','=','O','l','d','M','s','g','I','d',0},
    ATTR_TIMEOUT_SECONDS_VAL[sizeof("TimeoutSeconds")*sizeof(CciChar)] =
    {'T','i','m','e','o','u','t','S','e','c','o','n','d','s',0},
    ATTR_TIMEOUT_SECONDS_DEFAULT_VALUE_VAL[sizeof("0")*sizeof(CciChar)] =
    {'0',0},
    ATTR_NUM_APPLICATIONS_VAL[sizeof("NumberOfApplications")*sizeof(CciChar)] =
    {'N','u','m','b','e','r','O','f','A','p','p','l','i','c','a','t','i','o','n','s',0},
    ATTR_NUM_APPLICATIONS_DEFAULT_VALUE_VAL[sizeof("1")*sizeof(CciChar)] =
    {'1',0},
    ATTR_POSTIT_SCOPE_VAL[sizeof("PostitScope")*sizeof(CciChar)] =
    {'P','o','s','t','i','t','S','c','o','p','e',0},
    ATTR_POSTIT_SCOPE_DEFAULT_VALUE_VAL[sizeof("ExecutionGroup")*sizeof(CciChar)] =
    {'E','x','e','c','u','t','i','o','n','G','r','o','u','p',0},
    MATCH_CORRELID_TO_MSGID_VAL[sizeof("CorrelId=OldMsgId")*sizeof(CciChar)] =
    {'C','o','r','r','e','l','I','d','=','O','l','d','M','s','g','I','d',0},
    MATCH_MSGID_TO_MSGID_VAL[sizeof("MsgId=OldMsgId")*sizeof(CciChar)] =
    {'M','s','g','I','d','=','O','l','d','M','s','g','I','d',0},
    MATCH_CORRELID_TO_CORRELID_VAL[sizeof("CorrelId=OldCorrelId")*sizeof(CciChar)] =
    {'C','o','r','r','e','l','I','d','=','O','l','d','C','o','r','r','e','l','I','d',0},
    MATCH_MSGID_TO_CORRELID_VAL[sizeof("MsgId=OldCorrelId")*sizeof(CciChar)] =
    {'M','s','g','I','d','=','O','l','d','C','o','r','r','e','l','I','d',0},
    MATCH_BOTHIDS_VAL[sizeof("MsgId+CorrelId=OldMsgId+OldCorrelId")*sizeof(CciChar)] =
    {'M','s','g','I','d','+','C','o','r','r','e','l','I','d','=','O','l','d','M','s','g','I','d','+','O','l','d','C','o','r','r','e','l','I','d',0},
    MATCH_ALL_MESSAGES_VAL[sizeof("AllMessages")*sizeof(CciChar)] =
    {'A','l','l','M','e','s','s','a','g','e','s',0},
    SCOPE_VALUE_EG_VAL[sizeof("ExecutionGroup")*sizeof(CciChar)] =
    {'E','x','e','c','u','t','i','o','n','G','r','o','u','p',0},
    SCOPE_VALUE_BROKER_VAL[sizeof("Broker")*sizeof(CciChar)] =
    {'B','r','o','k','e','r',0},
    TERM_NO_DATA_COPIED_VAL[sizeof("noDataCopied")*sizeof(CciChar)] =
    {'n','o','D','a','t','a','C','o','p','i','e','d',0},
    TERM_NO_MATCH_VAL[sizeof("noMatch")*sizeof(CciChar)] =
    {'n','o','M','a','t','c','h',0},
    ROOT_VAL[sizeof("Root")*sizeof(CciChar)] =
    {'R','o','o','t',0},
    ROOT_DOT_VAL[sizeof("Root.")*sizeof(CciChar)] =
    {'R','o','o','t','.',0},
    NULL_LITERAL_VAL[sizeof("null")*sizeof(CciChar)] =
    {'n','u','l','l',0},
    POSTIT_PLUGIN_FACTORY_VAL[sizeof("PostitPlugInFactory")*sizeof(CciChar)] =
    {'P','o','s','t','i','t','P','l','u','g','I','n','F','a','c','t','o','r','y',0};
#else
extern CciChar 
    PLUGIN_MESSAGE_CATALOGUE_VAL[],
    POSTIT_CREATE_NODE_VAL[],
    POSTIT_APPLY_NODE_VAL[],
    POSTIT_DELETE_NODE_VAL[],
    ATTR_LABEL_VAL[],
    ATTR_USER_TRACE_LEVEL_VAL[],
    ATTR_TRACE_LEVEL_VAL[],
    ATTR_USER_TRACE_FILTER_VAL[],
    ATTR_TRACE_FILTER_VAL[],
    TERM_IN_VAL[],
    TERM_OUT_VAL[],
    TERM_FAILURE_VAL[],
    ATTR_POSTIT_NAME_VAL[],
    ATTR_POSTIT_NAME_DEFAULT_VALUE_VAL[],
    ATTR_COPY_DATA_FROM_VAL[],
    ATTR_COPY_DATA_FROM_DEFAULT_VALUE_VAL[],
    ATTR_COPY_DATA_TO_VAL[],
    ATTR_COPY_DATA_TO_DEFAULT_VALUE_VAL[],
    ATTR_MATCH_ON_VAL[],
    ATTR_MATCH_ON_DEFAULT_VALUE_VAL[],
    ATTR_TIMEOUT_SECONDS_VAL[],
    ATTR_TIMEOUT_SECONDS_DEFAULT_VALUE_VAL[],
    ATTR_NUM_APPLICATIONS_VAL[],
    ATTR_NUM_APPLICATIONS_DEFAULT_VALUE_VAL[],
    ATTR_POSTIT_SCOPE_VAL[],
    ATTR_POSTIT_SCOPE_DEFAULT_VALUE_VAL[],
    MATCH_CORRELID_TO_MSGID_VAL[],
    MATCH_MSGID_TO_MSGID_VAL[],
    MATCH_CORRELID_TO_CORRELID_VAL[],
    MATCH_MSGID_TO_CORRELID_VAL[],
    MATCH_BOTHIDS_VAL[],
    MATCH_ALL_MESSAGES_VAL[],
    SCOPE_VALUE_EG_VAL[],
    SCOPE_VALUE_BROKER_VAL[],
    TERM_NO_DATA_COPIED_VAL[],
    TERM_NO_MATCH_VAL[],
    ROOT_VAL[],
    ROOT_DOT_VAL[],
    NULL_LITERAL_VAL[],
    POSTIT_PLUGIN_FACTORY_VAL[];
#endif
#endif


/* define the initialisation macro */
#if defined(WIN32) || defined(_AIX)
#define POSTIT_CONSTANTS_DEFAULTS \
    L"MQSIV2_postit", \
    L"PostitCreateNode", \
    L"PostitApplyNode", \
    L"PostitDeleteNode", \
    L"label", \
    L"userTraceLevel", \
    L"traceLevel", \
    L"userTraceFilter", \
    L"traceFilter", \
    L"in", \
    L"out", \
    L"failure", \
    L"PostitName", \
    L"", \
    L"CopyDataFrom", \
    L"Root.MQMD.ReplyToQ", \
    L"CopyDataTo", \
    L"Root.MQMD.ReplyToQ", \
    L"MatchOn", \
    L"CorrelId=OldMsgId", \
    L"TimeoutSeconds", \
    L"0", \
    L"NumberOfApplications", \
    L"1", \
    L"PostitScope", \
    L"ExecutionGroup", \
    L"CorrelId=OldMsgId", \
    L"MsgId=OldMsgId", \
    L"CorrelId=OldCorrelId", \
    L"MsgId=OldCorrelId", \
    L"MsgId+CorrelId=OldMsgId+OldCorrelId", \
    L"AllMessages", \
    L"ExecutionGroup", \
    L"Broker", \
    L"noDataCopied", \
    L"noMatch", \
    L"Root", \
    L"Root.", \
    L"null", \
    L"PostitPlugInFactory"


#elif defined(_SOLARIS) || defined(_HPUX)

#define POSTIT_CONSTANTS_DEFAULTS \
    PLUGIN_MESSAGE_CATALOGUE_VAL, \
    POSTIT_CREATE_NODE_VAL, \
    POSTIT_APPLY_NODE_VAL, \
    POSTIT_DELETE_NODE_VAL, \
    ATTR_LABEL_VAL, \
    ATTR_USER_TRACE_LEVEL_VAL, \
    ATTR_TRACE_LEVEL_VAL, \
    ATTR_USER_TRACE_FILTER_VAL, \
    ATTR_TRACE_FILTER_VAL, \
    TERM_IN_VAL, \
    TERM_OUT_VAL, \
    TERM_FAILURE_VAL, \
    ATTR_POSTIT_NAME_VAL, \
    ATTR_POSTIT_NAME_DEFAULT_VALUE_VAL, \
    ATTR_COPY_DATA_FROM_VAL, \
    ATTR_COPY_DATA_FROM_DEFAULT_VALUE_VAL, \
    ATTR_COPY_DATA_TO_VAL, \
    ATTR_COPY_DATA_TO_DEFAULT_VALUE_VAL, \
    ATTR_MATCH_ON_VAL, \
    ATTR_MATCH_ON_DEFAULT_VALUE_VAL, \
    ATTR_TIMEOUT_SECONDS_VAL, \
    ATTR_TIMEOUT_SECONDS_DEFAULT_VALUE_VAL, \
    ATTR_NUM_APPLICATIONS_VAL, \
    ATTR_NUM_APPLICATIONS_DEFAULT_VALUE_VAL, \
    ATTR_POSTIT_SCOPE_VAL, \
    ATTR_POSTIT_SCOPE_DEFAULT_VALUE_VAL, \
    MATCH_CORRELID_TO_MSGID_VAL, \
    MATCH_MSGID_TO_MSGID_VAL, \
    MATCH_CORRELID_TO_CORRELID_VAL, \
    MATCH_MSGID_TO_CORRELID_VAL, \
    MATCH_BOTHIDS_VAL, \
    MATCH_ALL_MESSAGES_VAL, \
    SCOPE_VALUE_EG_VAL, \
    SCOPE_VALUE_BROKER_VAL, \
    TERM_NO_DATA_COPIED_VAL, \
    TERM_NO_MATCH_VAL, \
    ROOT_VAL, \
    ROOT_DOT_VAL, \
    NULL_LITERAL_VAL, \
    POSTIT_PLUGIN_FACTORY_VAL
#endif


/* finally, define the global initializer structure */
#if defined(GLOBAL_POSTIT_DATA)
    postitConstants_t C = {POSTIT_CONSTANTS_DEFAULTS};
#else
    extern postitConstants_t C;
#endif


#define POSTIT_CREATE_NODE_MB "PostitCreateNode"
#define POSTIT_APPLY_NODE_MB "PostitApplyNode"
#define POSTIT_DELETE_NODE_MB "PostitDeleteNode"


#define NULL_24 \
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
#define NULL_48 \
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
#define NULL_48_AND_TRAILING_NULL \
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0

#endif
